@@ -1,6 +1,6 @@
 #!/usr/bin/python
 
-## Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012, 2013 Red Hat, Inc.
+## Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2015 Red Hat, Inc.
 ## Copyright (C) 2008 Novell, Inc.
 ## Author: Tim Waugh <twaugh@redhat.com>
 
@@ -104,6 +104,10 @@ class _IPPConnectionThread(threading.Thread):
                 # Our signal to quit.
                 self._queue.task_done ()
                 break
+            elif self._destroyed:
+                # Just mark all tasks done
+                self._queue.task_done ()
+                continue
 
             self.idle = False
             (fn, args, kwds, rh, eh, ah) = item
@@ -155,7 +159,6 @@ class _IPPConnectionThread(threading.Thread):
             self._queue.task_done ()
 
         debugprint ("Thread exiting")
-        self._destroyed = True
         del self._conn # already destroyed
         del self._reply_handler
         del self._error_handler
@@ -166,6 +169,10 @@ class _IPPConnectionThread(threading.Thread):
 
         cups.setPasswordCB2 (None)
 
+    def stop (self):
+        self._destroyed = True
+        self._queue.put (None)
+
     def _auth (self, prompt, conn=None, method=None, resource=None):
         def prompt_auth (prompt):
             Gdk.threads_enter ()
@@ -263,12 +270,12 @@ class IPPConnection:
             delattr (self, binding)
 
         if self.thread.isAlive ():
+            debugprint ("Stopping worker thread")
+            self.thread.stop ()
             GLib.timeout_add_seconds (1, self._reap_thread)
 
     def _reap_thread (self):
         if self.thread.idle:
-            debugprint ("Putting None on the task queue")
-            self.queue.put (None)
             self.queue.join ()
             return False
 
@@ -460,11 +467,10 @@ class _IPPAuthOperation:
         # If we've previously prompted, explain why we're prompting again.
         if self._dialog_shown:
             d = Gtk.MessageDialog (parent=self._conn.parent,
-                                   flags=Gtk.DialogFlags.MODAL |
-                                         Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                                   modal=True, destroy_with_parent=True,
                                    message_type=Gtk.MessageType.ERROR,
                                    buttons=Gtk.ButtonsType.CLOSE,
-                                   message_format=_("Not authorized"))
+                                   text=_("Not authorized"))
             d.format_secondary_text (_("The password may be incorrect."))
             d.run ()
             d.destroy ()
@@ -556,11 +562,10 @@ class _IPPAuthOperation:
             msg = _("CUPS server error (%s)") % op
 
         d = Gtk.MessageDialog (parent=self._conn.parent,
-                               flags=Gtk.DialogFlags.MODAL |
-                                     Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                               modal=True, destroy_with_parent=True,
                                message_type=Gtk.MessageType.ERROR,
                                buttons=Gtk.ButtonsType.NONE,
-                               message_format=msg)
+                               text=msg)
 
         if self._client_fn == None and type (exc) == RuntimeError:
             # This was a connection failure.
