@@ -289,7 +289,7 @@ class OpenPrinting:
                             dict[attribute] = _normalize_space (element.text)
 
                     element = driver.find ('licensetext')
-                    if element != None:
+                    if element != None and element.text != None:
                         dict['licensetext'] = element.text
 
                     for boolean in ['nonfreesoftware', 'recommended',
