@@ -2,7 +2,7 @@
 
 ## system-config-printer
 
-## Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2014 Red Hat, Inc.
+## Copyright (C) 2006, 2007, 2008, 2009, 2010, 2011, 2014, 2015 Red Hat, Inc.
 ## Copyright (C) 2006 Florian Festi <ffesti@redhat.com>
 ## Copyright (C) 2006, 2007, 2008, 2009 Tim Waugh <twaugh@redhat.com>
 
@@ -92,7 +92,7 @@ _HP_MODEL_BY_NAME = {
 }
 
 _RE_turboprint = re.compile ("turboprint")
-_RE_version_numbers = re.compile (" v\d(?:\d*\.\d+)?(?: |$)")
+_RE_version_numbers = re.compile (" v(?:er\.)?\d(?:\d*\.\d+)?(?: |$)")
 _RE_ignore_suffix = re.compile (","
                                 "| hpijs"
                                 "| foomatic/"
@@ -201,8 +201,9 @@ def ppdMakeModelSplit (ppd_make_and_model):
             if mfr:
                 make = mfr
 
-    # HP PostScript PPDs give NickNames like:
+    # HP and Canon PostScript PPDs give NickNames like:
     # *NickName: "HP LaserJet 4 Plus v2013.111 Postscript (recommended)"
+    # *NickName: "Canon MG4100 series Ver.3.90"
     # Find the version number and truncate at that point.  But beware,
     # other model names can legitimately look like version numbers,
     # e.g. Epson PX V500.
@@ -211,9 +212,9 @@ def ppdMakeModelSplit (ppd_make_and_model):
     modell = model.lower ()
     v = modell.find (" v")
     if v != -1:
-        # Look for " v" followed by a digit, optionally followed by more
-        # digits, a dot, and more digits; and terminated by a space of the
-        # end of the line.
+        # Look for " v" or " ver." followed by a digit, optionally
+        # followed by more digits, a dot, and more digits; and
+        # terminated by a space of the end of the line.
         vmatch = _RE_version_numbers.search (modell)
         if vmatch:
             # Found it -- truncate at that point.
@@ -715,9 +716,15 @@ class PPDs:
                     fit[each] = self.FIT_EXACT_CMD
                     _debugprint (self.FIT_EXACT_CMD + ": %s" % each)
 
-            _debugprint ("Removed %s due to CMD mis-match" % failed)
-            for each in failed:
-                del fit[each]
+            if len (failed) < len ([d for (d, m) in fit.items ()
+                                    if m != 'generic']):
+                _debugprint ("Removed %s due to CMD mis-match" % failed)
+                for each in failed:
+                    del fit[each]
+            else:
+                _debugprint ("Not removing %s " % failed +
+                             "due to CMD mis-match as it would "
+                             "leave nothing good")
 
         if not fit:
             fallbacks = ["textonly.ppd", "postscript.ppd"]
@@ -1227,7 +1234,7 @@ def _self_test(argv):
          "DES:Hewlett-Packard DeskJet 990C;", 0, "HP DeskJet 990C"),
         ("CLASS:PRINTER;MODEL:HP LaserJet 6MP;MANUFACTURER:Hewlett-Packard;"
          "DESCRIPTION:Hewlett-Packard LaserJet 6MP Printer;"
-         "COMMAND SET:PJL,MLC,PCLXL,PCL,POSTSCRIPT;", 0, "HP LaserJet 6MP"),
+         "COMMAND SET:PJL,MLC,PCLXL,PCL,POSTSCRIPT;", 0, "HP LaserJet (6P/)?6MP"),
         # Canon PIXMA iP3000 (from gutenprint)
         ("MFG:Canon;CMD:BJL,BJRaster3,BSCCe;SOJ:TXT01;MDL:iP3000;CLS:PRINTER;"
          "DES:Canon iP3000;VER:1.09;STA:10;FSI:03;", 1, "Canon PIXMA iP3000"),
