@@ -1,8 +1,8 @@
 # vim: set ts=4 sw=4 et: coding=UTF-8
 #
-# Copyright (C) 2008 Novell, Inc.
-# Copyright (C) 2008, 2009, 2010, 2012 Red Hat, Inc.
-# Copyright (C) 2008, 2009, 2010, 2012 Tim Waugh <twaugh@redhat.com>
+# Copyright (C) 2008, 2013 Novell, Inc.
+# Copyright (C) 2008, 2009, 2010, 2012, 2014 Red Hat, Inc.
+# Copyright (C) 2008, 2009, 2010, 2012, 2014 Tim Waugh <twaugh@redhat.com>
 #
 # Authors: Vincent Untz
 #
@@ -131,8 +131,9 @@ class Connection:
                         else:
                             return retval
                 break
-            except dbus.exceptions.DBusException, e:
+            except dbus.exceptions.DBusException as e:
                 if e.get_dbus_name() == CUPS_PK_NEED_AUTH:
+                    debugprint ("DBus exception: %s" % e.get_dbus_message ())
                     raise cups.IPPError(cups.IPP_NOT_AUTHORIZED, 'pkcancel')
 
                 break
@@ -141,7 +142,7 @@ class Connection:
         # exception that wasn't handled, or an error in the mechanism itself)
         if pk_retval != '':
             debugprint ('PolicyKit call to %s did not work: %s' %
-                        (pk_function_name, pk_retval))
+                        (pk_function_name, repr (pk_retval)))
             return fallback_function(*args, **kwds)
 
 
