@@ -29,11 +29,10 @@ gettext.install(domain=config.PACKAGE, localedir=config.localedir, unicode=True)
 
 def show_dialog (title, text, type, parent=None):
     dialog = Gtk.MessageDialog (parent=parent,
-                                flags=Gtk.DialogFlags.MODAL |
-                                      Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                                modal=True, destroy_with_parent=True,
                                 message_type=type,
                                 buttons=Gtk.ButtonsType.OK,
-                                message_format=title)
+                                text=title)
     dialog.format_secondary_text (text)
     dialog.run ()
     dialog.destroy ()
