@@ -1,5 +1,5 @@
 
-## Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014 Red Hat, Inc.
+## Copyright (C) 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015 Red Hat, Inc.
 ## Authors:
 ##  Tim Waugh <twaugh@redhat.com>
 ##  Jiri Popelka <jpopelka@redhat.com>
@@ -24,6 +24,7 @@ import cups
 import dbus
 import dbus.glib
 import dbus.service
+import threading
 from gi.repository import Notify
 from gi.repository import GLib
 from gi.repository import GObject
@@ -315,6 +316,7 @@ class JobViewer (GtkGUI):
                                    'job-printer-uri',
                                    'job-state',
                                    'time-at-creation',
+                                   'auth-info-required',
                                    'job-preserved'])
 
     __gsignals__ = {
@@ -553,6 +555,7 @@ class JobViewer (GtkGUI):
         self.port = cups.getPort ()
         self.encryption = cups.getEncryption ()
         self.monitor = monitor.Monitor (bus=bus, my_jobs=my_jobs,
+                                        specific_dests=specific_dests,
                                         host=self.host, port=self.port,
                                         encryption=self.encryption)
         self.monitor.connect ('refresh', self.on_refresh)
@@ -862,8 +865,13 @@ class JobViewer (GtkGUI):
             s = int (jstate)
 
             if s in [cups.IPP_JOB_HELD, cups.IPP_JOB_STOPPED]:
-                jattrs = ['job-state', 'job-hold-until']
+                jattrs = ['job-state', 'job-hold-until', 'job-printer-uri']
                 pattrs = ['auth-info-required', 'device-uri']
+                # The current job-printer-uri may differ from the one that
+                # is returned when we request it over the connection.
+                # So while we use it to query the printer attributes we
+                # Update it afterwards to make sure that we really
+                # have the one cups uses in the job attributes.
                 uri = data.get ('job-printer-uri')
                 c = authconn.Connection (self.JobsWindow,
                                          host=self.host,
@@ -916,6 +924,8 @@ class JobViewer (GtkGUI):
                                      data.get ('job-printer-uri'),
                                      data.get ('auth-info-required', []),
                                      self.applet)
+
+        self.submenu_set = False
         self.update_sensitivity ()
 
     def get_authentication (self, job, device_uri, printer_uri,
@@ -1265,7 +1275,9 @@ class JobViewer (GtkGUI):
                 menuitem = Gtk.MenuItem (label=printer)
                 menuitem.set_sensitive (uri != None)
                 menuitem.show ()
-                menuitem.connect ('activate', self.on_job_move_activate, uri)
+                self._submenu_connect_hack (menuitem,
+                                            self.on_job_move_activate,
+                                            uri)
                 printers_menu.append (menuitem)
 
             self.move_job_menuitem.set_submenu (printers_menu)
@@ -1488,6 +1500,16 @@ class JobViewer (GtkGUI):
         del c
         self.update_monitor ()
 
+    def _submenu_connect_hack (self, item, callback, *args):
+        # See https://bugzilla.gnome.org/show_bug.cgi?id=695488
+        only_once = threading.Semaphore (1)
+        def handle_event (item, event=None):
+            if only_once.acquire (False):
+                GObject.idle_add (callback, item, *args)
+
+        return (item.connect ('button-press-event', handle_event),
+                item.connect ('activate', handle_event))
+
     def on_job_move_activate(self, menuitem, job_printer_uri):
         try:
             c = authconn.Connection (self.JobsWindow,
@@ -2367,7 +2389,7 @@ class JobViewer (GtkGUI):
                           cups.IPP_JOB_CANCELED: _("Canceled"),
                           cups.IPP_JOB_ABORTED: _("Aborted"),
                           cups.IPP_JOB_COMPLETED: _("Completed") }[s]
-            except IndexError:
+            except KeyError:
                 pass
 
         if state == None:
