@@ -168,11 +168,10 @@ class Option:
         while parent != None and not isinstance (parent, Gtk.Window):
             parent = parent.get_parent ()
         dialog = Gtk.MessageDialog (parent=parent,
-                                    flags=Gtk.DialogFlags.DESTROY_WITH_PARENT |
-                                          Gtk.DialogFlags.MODAL,
+                                    modal=True, destroy_with_parent=True,
                                     message_type=Gtk.MessageType.WARNING,
                                     buttons=Gtk.ButtonsType.CLOSE,
-                                    message_format=self.conflict_message)
+                                    text=self.conflict_message)
         dialog.run()
         dialog.destroy()
         
