@@ -84,8 +84,7 @@ class AuthContext:
 
         if self.dialog_shown:
             d = Gtk.MessageDialog (parent=self.parent,
-                                   flags=Gtk.DialogFlags.MODAL |
-                                         Gtk.DialogFlags.DESTROY_WITH_PARENT,
+                                   modal=True, destroy_with_parent=True,
                                    message_type=Gtk.MessageType.ERROR,
                                    buttons=Gtk.ButtonsType.CLOSE)
             d.set_title (_("Not authorized"))
